@@ -499,6 +499,24 @@ class WithConcurrentGetOrCreate(object):
         return obj, created
 
 
+class VerboseNameGetter(object):
+    def __init__(self, model):
+        self.model = model
+
+    def __hasattr__(self, name):
+        try:
+            name = self.model._meta.get_field_by_name(name)[0].verbose_name
+            return True
+        except:
+            return False
+
+    def __getattr__(self, name):
+        try:
+            return self.model._meta.get_field_by_name(name)[0].verbose_name
+        except:
+            return None
+
+
 class MACAddressFormField(fields.RegexField):
     default_error_messages = {
         'invalid': _(u'Enter a valid MAC address.'),
@@ -524,9 +542,13 @@ class MACAddressField(db.Field):
         defaults.update(kwargs)
         return super(MACAddressField, self).formfield(**defaults)
 
-    def get_db_prep_value(self, value):
+    @staticmethod
+    def normalize(value):
         return filter(lambda ch: ch not in ':-', value).upper()
 
+    def get_db_prep_value(self, value):
+        return self.normalize(value)
+
 
 # For now this needs to be at the end of the file.
 # FIXME: move it where it's supposed to be.
